@@ -109,17 +109,18 @@ void MH_FormationMLEblockdiagTNT(MHproposal *MHp, Network *nwp)
     return;
   }
 
+  double logratio=0;
   BD_LOOP({
       if(ndedges != 0 && (nempty == 0 || unif_rand() < comp)) { /* Select a discordant dyad at random */
       GetRandEdge(&tail, &head, &discord);
       
       if(nempty==0){
-	MHp->logratio += log(ndedges*(1-comp));
+	logratio = log(ndedges*(1-comp));
       }else{
 	if(ndedges==1){
-	  MHp->logratio += log(1.0 / (nempty + 1) /comp);
+	  logratio = log(1.0 / (nempty + 1) /comp);
 	}else{
-	  MHp->logratio += log((double) ndedges / (nempty + 1) / odds);
+	  logratio = log((double) ndedges / (nempty + 1) / odds);
 	}
       }
     }else{ /* select an empty dyad in nwp[0] at random */
@@ -141,12 +142,12 @@ void MH_FormationMLEblockdiagTNT(MHproposal *MHp, Network *nwp)
       }while(EdgetreeSearch(tail,head,nwp->outedges));
       
       if(ndedges==0){
-        MHp->logratio += log(nempty*comp);
+        logratio = log(nempty*comp);
       }else{
 	if(nempty==1){
-	  MHp->logratio += log(1.0 / ndyads / (1-comp));
+	  logratio = log(1.0 / ndyads / (1-comp));
 	}else{
-	  MHp->logratio += log((double) nempty / (ndedges+1) * odds);
+	  logratio = log((double) nempty / (ndedges+1) * odds);
 	}
       }
     }
@@ -155,4 +156,5 @@ void MH_FormationMLEblockdiagTNT(MHproposal *MHp, Network *nwp)
     Mhead[0]=head;
     
     });
+  MHp->logratio = logratio;
 }
