@@ -79,34 +79,36 @@ void MH_FormationTNT (MHproposal *MHp, Network *nwp)
     Mhead[0]=MH_IMPOSSIBLE;
     return;
   }
-  
+
+  double logratio=0;
   BD_LOOP({
       if(ndedges != 0 && (nempty == 0 || unif_rand() < comp)) { /* Select a discordant dyad at random */
 	GetRandEdge(Mtail, Mhead, nwp+1);
 	
 	if(nempty==0){
-	  MHp->logratio += log(ndedges*(1-comp));
+	  logratio = log(ndedges*(1-comp));
 	}else{
 	  if(ndedges==1){
-	    MHp->logratio += log(1.0 / (nempty + 1) /comp);
+	    logratio = log(1.0 / (nempty + 1) /comp);
 	  }else{
-	    MHp->logratio += log((double) ndedges / (nempty + 1) / odds);
+	    logratio = log((double) ndedges / (nempty + 1) / odds);
 	  }
 	}
       }else{ /* select an empty dyad in nwp[0] at random */
 	GetRandNonedge(Mtail, Mhead, nwp);
 	
 	if(ndedges==0){
-	  MHp->logratio += log(nempty*comp);
+	  logratio = log(nempty*comp);
 	}else{
 	  if(nempty==1){
-	    MHp->logratio += log(1.0 / ndyads / (1-comp));
+	    logratio = log(1.0 / ndyads / (1-comp));
 	  }else{
-	    MHp->logratio += log((double) nempty / (ndedges+1) * odds);
+	    logratio = log((double) nempty / (ndedges+1) * odds);
 	  }
 	}
       }
     });
+  MHp->logratio += logratio;
   //   Rprintf("nedges %d reference nddyads %d h %d t %d MHp->ratio %f\n", 
   //	    nwp[0].nedges, nwp[1].nedges, tail, head, MHp->ratio); 
 }
