@@ -1,6 +1,4 @@
-# test simulate.networkDynamic using example code
-require(networkDynamic)
-require(tergm)
+library(tergm)
 
 logit<-function(p)log(p/(1-p))
 coef.form.f<-function(coef.diss,density) -log(((1+exp(coef.diss))/(density/(1-density)))-1)
@@ -145,7 +143,83 @@ if(!all(network.dynamic.check(msm.sim,complete=FALSE)$dyad.checks)){
   stop('vertex dynamics in stergm sim created inconsistent dyads')
 }
 
+# at this point msm.sim has observations as far as 2.  Try sampling at 2 and upating from (2,3)
+msm.sim <- simulate(msm.sim,
+                    formation=formation,
+                    dissolution=~edges,
+                    coef.form=coef.form,
+                    coef.diss=coef.diss,
+                    time.slices = 1, time.start=2,time.offset=0,
+                    monitor="all",
+                    verbose=T
+)
+
+if (max(unlist((msm.sim%n%'net.obs.period')$observations)) > 3){
+  stop("simulate.networkDynamic updated net.obs.period inappropriately when time.start and time.offset was explicitly set" )
+}
+if (!all(get.change.times(msm.sim)==0:2)){
+  stop("simulate.networkDynamic updated edge spells inappropriately when time.start and time.offset was explicitly set")
+}
+
+# try it again to make sure nothing got mangled
+msm.sim <- simulate(msm.sim,
+                    formation=formation,
+                    dissolution=~edges,
+                    coef.form=coef.form,
+                    coef.diss=coef.diss,
+                    time.slices = 1, time.start=3,time.offset=0,
+                    monitor="all",
+                    verbose=T
+)
+if (max(unlist((msm.sim%n%'net.obs.period')$observations)) > 4){
+  stop("simulate.networkDynamic updated net.obs.period inappropriately when time.start and time.offset was explicitly set" )
+}
+if (!all(get.change.times(msm.sim)==0:3)){
+  stop("simulate.networkDynamic updated edge spells inappropriately when time.start and time.offset was explicitly set")
+}
 
 
+# check that vertex ids in changes are correctly translated
+dyn<-as.networkDynamic(network.initialize(4))
+deactivate.vertices(dyn,v=1)
+# define stergm that should toggle on all ties
+changes<-simulate.networkDynamic(dyn,formation=~edges,dissolution=~edges,coef.form=1,coef.diss=0,output='changes')
+# check if any changes involve vertex 1 (shouldn't because it is inactive)
+if(any(changes[,2:3]==1)){
+  stop("simulate.networkDynamic returned changes involving an inactive vertex" )
+}
+
+
+mean.rel.dur <- 10
+msm.sim <- as.networkDynamic(network.initialize(1000,directed=F))
+#set.network.attribute(msm.sim,'net.obs.period',list(observations=list(c(-1,0)),
+#                                                    mode="discrete", time.increment=1,time.unit="step"))
+formation <- ~edges
+dissolution <- ~offset(edges)
+target.stats <- 400
+coef.diss <- log(mean.rel.dur-1)
+formation.with.stnet <- update.formula(formation,msm.startnet~.)
+# simulate a set of edges to use as the starting point for the network
+msm.startnet <- network.collapse(msm.sim,at=0)
+msm.est <- ergm(formation.with.stnet,target.stats=target.stats)
+coef.form <- msm.est$coef
+coef.form[1] <- coef.form[1] - coef.diss
+msm.edgelist <- as.edgelist(simulate(msm.est))
+add.edges(msm.sim,msm.edgelist[,1],msm.edgelist[,2])
+
+msm.sim <- simulate(msm.sim,
+                    formation=formation,
+                    dissolution=~edges,
+                    coef.form=coef.form,
+                    coef.diss=coef.diss,
+                    time.slices = 1, time.start=0,time.offset=0,
+                    monitor="all",
+                    verbose=T
+)
+
+
+if(length((msm.sim%n%'net.obs.period')$observations)>1){
+  stop('simulate.networkDynamic mangled net.obs.period with time.offset=0 argument')
+}
 
 
